@@ -6,5 +6,5 @@ class Strategy:
     def __init__(self, scraper: 'LinkedinScraper'):
         self.scraper = scraper
 
-    def run(self, driver: webdriver, search_url: str, query: Query, location: str) -> None:
+    def run(self, driver: webdriver, search_url: str, query: Query, location: str, apply_link: bool) -> None:
         raise NotImplementedError('Must implement method in subclass')
